@@ -6,6 +6,7 @@ import (
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
+	configv1 "github.com/openshift/api/config/v1"
 	metal3iov1alpha1 "github.com/openshift/cluster-baremetal-operator/api/v1alpha1"
 	"github.com/openshift/library-go/pkg/operator/events"
 )
@@ -18,4 +19,5 @@ type ProvisioningInfo struct {
 	Namespace        string
 	Images           *Images
 	PodLabelSelector *metav1.LabelSelector
+	Proxy            *configv1.Proxy
 }
